#include <TFT.h>
#include <SPI.h>

#define CPU			0
#define HUMAN		1

// pentru ecran
#define cs 10
#define dc 9
#define rst 8

// pentru MELODIE START
#define NOTE_START1  262
#define NOTE_START_2  330
#define NOTE_START_3  392
#define NOTE_START_4  523

// pentru MELODIE CASTIG
#define NOTE_CASTIG_1   500
#define NOTE_CASTIG_2  100
#define NOTE_CASTIG_3  50
#define NOTE_CASTIG_4  700
#define NOTE_CASTIG_5  400

// pentru MELODIE PIERDERE
#define NOTE_PIERDERE_1  262
#define NOTE_PIERDERE_2  247
#define NOTE_PIERDERE_4  220
#define NOTE_PIERDERE_5  196
#define NOTE_PIERDERE_6  175

// pentru remiza
#define NOTE_REMIZA_1  262
#define NOTE_REMIZA_2  330
#define NOTE_REMIZA_3  392
#define NOTE_REMIZA_4  440

// pentru simboluri
#define NO_SYMBOL 0
#define X_SYMBOL  1
#define O_SYMBOL  2

// pentru butoane
#define BUTTON_UP       PD2
#define BUTTON_DOWN     PD6
#define BUTTON_LEFT     PD5
#define BUTTON_RIGHT    PD4
#define BUTTON_OK       PD7
#define BUTTON_EXIT     PB0


// pentru directii
#define UP			2
#define DOWN		6
#define LEFT		5
#define RIGHT		4
#define OK			7

// structura reprezentare celula din tabla de joc
struct cell {
	int8_t symbol;
	int16_t x, y;
	int16_t w, h;
};

// variabile globale
static struct cell board[3][3];
int8_t current_x = 0, current_y = 0;
TFT TFTscreen = TFT(cs, dc, rst);
int prev_button_state = LOW;  
int button_state; 
// Calculăm poziția x pentru a centra textul
int textWidth = 7 * 6 * 2; // 7 caractere, lățime medie 6 pixeli per caracter, mărime text 2
int x = (TFTscreen.width() - textWidth) / 2;
int gridX = (TFTscreen.width() - 10) / 2; 
int gridY = 35;
int8_t player = CPU;
int lost, won, draw = 0;
int no_games = 1;
bool game_running = false;
int apasare_exit = 0;
int buzzer = 3;


// configurari pini
void configurare_pini() {
    // Configurare pinul D12 (buton START) ca intrare cu pull-up activat
    DDRB &= ~(1 << DDB4); // Setează pinul D12 ca intrare 
    PORTB |= (1 << PORTB4); // Activează pull-up pentru pinul D12 
    // Setează pinii butoanelor ca pinii de intrare
    DDRD &= ~((1 << BUTTON_UP) | (1 << BUTTON_DOWN) | (1 << BUTTON_LEFT) | (1 << BUTTON_RIGHT) | (1 << BUTTON_OK));
    // Activează rezistențele de pull-up pentru butoanele conectate la GND
    PORTD |= (1 << BUTTON_UP) | (1 << BUTTON_DOWN) | (1 << BUTTON_LEFT) | (1 << BUTTON_RIGHT) | (1 << BUTTON_OK);
    // pentru button_exit (PB0)
    DDRB &= ~(1 << BUTTON_EXIT);
    PORTB |= (1 << BUTTON_EXIT);
}

// verifica daca un anumit buton e apasat
int citeste_butoane(uint8_t button) {
    // Verifică dacă butonul este apăsat
    if (!(PIND & (1 << button))) {
        _delay_ms(50);
        if (!(PIND & (1 << button))) {
            _delay_ms(50);
            if (!(PIND & (1 << button)))
                return 1; // Returnează 1 dacă butonul este apăsat
        }
    }
    return 0; // Returnează 0 dacă butonul nu este apăsat
}

// realizare mutare in functie de butoane
void mutare(int8_t direction) {
    // Salvează poziția curentă a celulei selectate anterior
    struct cell c = board[current_x][current_y];
    cell_border_set(c.x, c.y, c.w, c.h, ST7735_BLACK);

    switch (direction) {
        case UP:
            if (current_x == 0) {
              current_x = 2;
            }
            else current_x--;
            break;
        case DOWN:
            if (current_x == 2) current_x = 0;
            else current_x++;
            break;
        case LEFT:
            if (current_y == 0) current_y = 2;
            else current_y--;
            break;
        case RIGHT:
            if (current_y == 2) current_y = 0;
            else current_y++;
            break;
        case OK:
            board[current_x][current_y].symbol = X_SYMBOL;
            deseneaza_simbol(board[current_x][current_y].x, board[current_x][current_y].y, board[current_x][current_y].w, board[current_x][current_y].h, X_SYMBOL);
            break;
        default:
            break;
        
    }

    // Evidențiază celula nou selectată
    struct cell new_cell = board[current_x][current_y];
    highlight_cell(new_cell, ST7735_BLACK, ST7735_BLACK);

    // Șterge evidențierea celulei selectate anterior
    cell_border_set(c.x, c.y, c.w, c.h, ST7735_WHITE);
   
}


// Funcție pentru evidențierea unei celule
void highlight_cell(struct cell c, uint16_t color, uint16_t bg) {
    // Aici poți desena un contur în jurul celulei sau să aplici alte efecte vizuale
    TFTscreen.drawRect(c.x, c.y, c.w, c.h, color); // Exemplu: desenează un contur cu culoarea specificată

}

// Funcție pentru setarea bordurii unei celule
void cell_border_set(int16_t x, int16_t y, int16_t width, int16_t height, uint16_t color) {
    // Aici poți desena bordura sau să aplici alte modificări dorite
    TFTscreen.drawRect(x, y, width, height, color); // Exemplu: desenează o bordură cu culoarea specificată
}


// desenare floare
void drawFlower(int x, int y, int Rf, int Gf, int Bf, int R, int G, int B) {
  int centerX = x;
  int centerY = y;
  int petalRadius = 5;
  int centerRadius = 5;
  int petalDistance = 10;

  // Desenează centrul florii
  TFTscreen.fillCircle(centerX, centerY, centerRadius, TFTscreen.Color565(R, G, B)); // Galben

  // Desenează petalele
  for (int i = 0; i < 360; i += 60) {
    float angle = i * PI / 180;
    int petalX = centerX + cos(angle) * petalDistance;
    int petalY = centerY + sin(angle) * petalDistance;
    TFTscreen.fillCircle(petalX, petalY, petalRadius, TFTscreen.Color565(Rf, Gf, Bf)); // Roșu
  }
}


// printare pagina_initiala
void printare_initiala() {
  TFTscreen.begin();
  TFTscreen.setRotation(1);
  TFTscreen.background(94, 235, 52);

  TFTscreen.stroke(255, 0, 255); // Setează culoarea conturului la mov
  TFTscreen.textSize(2);

  // PRINTARE PAGINA START 
  drawFlower(80, 110, 0, 0, 255, 0, 255, 255);
  drawFlower(40, 110, 0, 0, 255, 0, 255, 255);
  drawFlower(120, 110, 0, 0, 255, 0, 255, 255);

  //WELCOME! pe centrul ecranului impreuna cu floricelele pana la apasarea butonului de START
  TFTscreen.stroke(155, 0, 0);  // Setează culoarea conturului la rosu
  TFTscreen.text("Welcome!", x, x);

  // Afișează titlul "X si 0"
  TFTscreen.stroke(125, 52, 235); // Setează culoarea conturului la mov
  TFTscreen.text("TIC-TAC-TOE", (TFTscreen.width() - (11 * 6 * 2)) / 2, 10);
  
}

// metoda pentru exit
void printare_exit() {
  TFTscreen.begin();
  TFTscreen.setRotation(1);
  TFTscreen.background(94, 235, 52);

  TFTscreen.stroke(255, 0, 255);  // Setează culoarea conturului la mov
  TFTscreen.textSize(2);

  drawFlower(80, 110, 0, 0, 255, 0, 255, 255);
  drawFlower(40, 110, 0, 0, 255, 0, 255, 255);
  drawFlower(120, 110, 0, 0, 255, 0, 255, 255);

  //GOOD BYE! pe centrul ecranului impreuna cu floricelele pana la apasarea butonului de START
  TFTscreen.stroke(255, 0, 0);  // Setează culoarea conturului la albastru
  TFTscreen.text("GOOD BYE!", x, x);

  // Afișează titlul "X si 0"
  TFTscreen.stroke(125, 52, 235);  // Setează culoarea conturului la mov
  TFTscreen.textSize(2);
  TFTscreen.text("TIC-TAC-TOE", (TFTscreen.width() - (11 * 6 * 2)) / 2, 10);

  // resetez variabilele 
  no_games = 1;
  won = 0;
  lost = 0;
  draw = 0;
  
}

// printare castig
void printare_castig() {
  TFTscreen.background(94, 235, 52);

  TFTscreen.stroke(255, 0, 255);  // Setează culoarea conturului la mov

  TFTscreen.textSize(2);
  // Afișează titlul "X si 0"
  TFTscreen.stroke(125, 52, 235);  // Setează culoarea conturului la mov
  TFTscreen.textSize(2);
  TFTscreen.text("CONGRATS!", (TFTscreen.width() - (9 * 6 * 2)) / 2, 10);

  drawSmiley(80, 80, 30);
  TFTscreen.stroke(125, 52, 235);
  delay(2000);
}

// printare esec
void printare_esec() {
  TFTscreen.background(94, 235, 52);

  TFTscreen.stroke(255, 0, 255);  // Setează culoarea conturului la mov

  TFTscreen.textSize(2);
  // Afișează titlul "X si 0"
  TFTscreen.stroke(125, 52, 235);  // Setează culoarea conturului la mov
  TFTscreen.textSize(2);
  TFTscreen.text("TRY AGAIN!", (TFTscreen.width() - (9 * 6 * 2)) / 2, 10);

  drawSadFace(80, 80, 30);
  TFTscreen.stroke(125, 52, 235);
  delay(2000);
}


// printare tabla_joc
void printare_tabla() {
      TFTscreen.background(94, 235, 52);
      TFTscreen.stroke(125, 52, 235); // Setează culoarea conturului la mov
      TFTscreen.textSize(2);
      TFTscreen.text("TIC-TAC-TOE", (TFTscreen.width() - (11 * 6 * 2)) / 2, 10);
      TFTscreen.stroke(255, 255, 255); // Setează culoarea conturului la alb

      // printare joc
      deseneaza_tabla(gridX, gridY, 84, 84);

      // INFO despre joc
      info_joc();
}

// printare info despre joc
void info_joc() {
  TFTscreen.textSize(1);

  // Setează textului conturului la negru
  TFTscreen.stroke(0, 0, 0);
  TFTscreen.fillRect(8, 35, 50, 10, TFTscreen.Color565(94, 235, 52)); 
  TFTscreen.text((String("NO.GAMES: ") + String(no_games)).c_str(), 8, 35);

  // Setează textului conturului la rosu
  TFTscreen.stroke(255, 0, 0); 
  TFTscreen.fillRect(8, 50, 50, 10, TFTscreen.Color565(94, 235, 52));
  TFTscreen.fillRect(9, 100, 50, 10, TFTscreen.Color565(94, 235, 52));
  TFTscreen.text((String("NO.WON: ") + String(won)).c_str(), 8, 50);

  // Setează textului conturului la albastru
  TFTscreen.stroke(0, 0, 255); 
  TFTscreen.fillRect(9, 65, 50, 10, TFTscreen.Color565(94, 235, 52));
  TFTscreen.text((String("NO.LOST: ") + String(lost)).c_str(), 9, 65);

  // Setează textului conturului la portocaliu
  TFTscreen.fillRect(9, 80, 50, 10, TFTscreen.Color565(94, 235, 52));
  TFTscreen.stroke(0, 255, 255); 
  TFTscreen.text((String("NO.DRAW: ") + String(draw)).c_str(), 9, 80);

  // Setează textului conturului la negru
  TFTscreen.stroke(0, 0, 0); 
  TFTscreen.fillRect(9, 100, 50, 10, TFTscreen.Color565(94, 235, 52));
  if (player == CPU) {
    TFTscreen.text("TURN: CPU", 9, 100);
  }
  else {
    TFTscreen.text("TURN: YOU", 9, 100);
    yourTurnSound();
  }
}



void deseneaza_simbol(int16_t cellX, int16_t cellY, int16_t cellW, int16_t cellH, int8_t symbol) {
    if (symbol == X_SYMBOL) {
        drawSmiley(cellX + cellW / 2, cellY + cellH / 2, cellW / 2 - 2);
    } else if (symbol == O_SYMBOL) {
        drawSadFace(cellX + cellW / 2, cellY + cellH / 2, cellW / 2 - 2);
    }
}

// deseneaza SmileyFace in loc de X
void drawSmiley(int x, int y, int radius) {
  // Desenează cercul exterior
  TFTscreen.stroke(0, 255, 255); // Galben
  TFTscreen.fill(0, 255, 255);   // Galben
  TFTscreen.circle(x, y, radius);

  // Desenează ochii
  TFTscreen.stroke(0, 0, 0); // Negru
  TFTscreen.fill(0, 0, 0);   // Negru
  TFTscreen.circle(x - radius / 3, y - radius / 3, radius / 5);
  TFTscreen.circle(x + radius / 3, y - radius / 3, radius / 5);

  // Desenează gura folosind linii
  TFTscreen.noFill();
  TFTscreen.stroke(0, 0, 0); // Negru
  int startX = x - radius / 3;
  int startY = y + radius / 6;
  int endX = x + radius / 3;
  int endY = y + radius / 6;
  int mouthWidth = endX - startX;
  int mouthHeight = radius / 4;

  for (int i = 0; i <= mouthWidth; i++) {
    int px = startX + i;
    int py = startY + (mouthHeight * sin((PI * i) / mouthWidth));
    TFTscreen.point(px, py);
  }
}

// deseneaza SadFace in loc de O
void drawSadFace(int x, int y, int radius) {
  // Desenează cercul exterior
  TFTscreen.stroke(0, 0, 255); // rosu
  TFTscreen.fill(0, 0, 255);   // rosu
  TFTscreen.circle(x, y, radius);

  // Desenează ochii
  TFTscreen.stroke(0, 0, 0); // Negru
  TFTscreen.fill(0, 0, 0);   // Negru
  TFTscreen.circle(x - radius / 3, y - radius / 3, radius / 5);
  TFTscreen.circle(x + radius / 3, y - radius / 3, radius / 5);

  // Desenează gura folosind linii (invers pentru a face o față tristă)
  TFTscreen.noFill();
  TFTscreen.stroke(0, 0, 0); // Negru
  int startX = x - radius / 3;
  int startY = y + radius / 3;
  int endX = x + radius / 3;
  int endY = y + radius / 3;
  int mouthWidth = endX - startX;
  int mouthHeight = radius / 4;

  for (int i = 0; i <= mouthWidth; i++) {
    int px = startX + i;
    int py = startY - (mouthHeight * sin((PI * i) / mouthWidth));
    TFTscreen.point(px, py);
  }
}

// desenare tabla joc
void deseneaza_tabla(int16_t x, int16_t y, int16_t width, int16_t height) {
    int16_t cell_width = width / 3;
    int16_t cell_height = height / 3;

    // Linii verticale
    for (int i = 0; i <= 3; i++) {
        TFTscreen.line(x + i * cell_width, y, x + i * cell_width, y + height);
    }

    // Linii orizontale
    for (int i = 0; i <= 3; i++) {
        TFTscreen.line(x, y + i * cell_height, x + width, y + i * cell_height);
    }
}

// initializare tabla de joc (matricea)
void board_init(int16_t x, int16_t y, int16_t width, int16_t height) {
    int16_t cell_width = width / 3;
    int16_t cell_height = height / 3;

    for (int i = 0; i < 3; i++) {
        for (int j = 0; j < 3; j++) {
            board[i][j].symbol = NO_SYMBOL;
            board[i][j].x = x + j * cell_width;
            board[i][j].y = y + i * cell_height;
            board[i][j].w = cell_width;
            board[i][j].h = cell_height;
        }
    }
}



// mutare CPU
void cpu_move()
{	
	int tries[24][3][2] = {{{0, 0}, {0, 1}, {0, 2}}, {{0, 0}, {0, 2}, {0, 1}}, {{0, 0}, {1, 0}, {2, 0}}, 
							{{0, 0}, {1, 1}, {2, 2}}, {{0, 0}, {2, 0}, {1, 0}}, {{0, 0}, {2, 2}, {1, 1}},
							{{0, 1}, {0, 2}, {0, 0}}, {{0, 1}, {1, 1}, {2, 1}}, {{0, 1}, {2, 1}, {1, 1}}, 
							{{0, 2}, {1, 1}, {2, 0}}, {{0, 2}, {1, 2}, {2, 2}}, {{0, 2}, {2, 0}, {1, 1}},
							{{0, 2}, {2, 2}, {1, 2}}, {{1, 0}, {1, 1}, {1, 2}}, {{1, 0}, {1, 2}, {1, 1}}, 
							{{1, 0}, {2, 0}, {0, 0}}, {{1, 1}, {1, 2}, {1, 0}}, {{1, 1}, {2, 0}, {0, 2}},
							{{1, 1}, {2, 1}, {0, 1}}, {{1, 1}, {2, 2}, {0, 0}}, {{1, 2}, {2, 2}, {0, 2}}, 
							{{2, 0}, {2, 1}, {2, 2}}, {{2, 0}, {2, 2}, {2, 1}}, {{2, 1}, {2, 2}, {2, 0}}};

	int8_t i, j, n = 0, index_x, index_y, incercare = 0;

	for (i = 0; i < 24; i++) {
		int8_t xi = tries[i][0][0];
		int8_t xj = tries[i][0][1];
		int8_t yi = tries[i][1][0];
		int8_t yj = tries[i][1][1];
		int8_t zi = tries[i][2][0];
		int8_t zj = tries[i][2][1];
		
		if (board[xi][xj].symbol == board[yi][yj].symbol && 
				board[xi][xj].symbol != NO_SYMBOL && 
					board[zi][zj].symbol == NO_SYMBOL) {
			index_x = zi;
			index_y = zj;
			incercare = 1;
			break;
		}
	}

	if (!incercare) {
		int free_cells[9];
		for (i = 0; i < 3; i++)
			for (j = 0; j < 3; j++)
				if (board[i][j].symbol == NO_SYMBOL)
					free_cells[n++] = i * 3 + j;
		
		int8_t index = free_cells[rand() % n];
		index_x = index / 3;
		index_y = index % 3;
	}

	board[index_x][index_y].symbol = O_SYMBOL;
	struct cell c = board[index_x][index_y];
	deseneaza_simbol(c.x, c.y, c.w, c.h, O_SYMBOL);
}


int won_game(int symb)
{
	int8_t i;
	
	for (i = 0; i < 3; i++) {
		if (board[i][0].symbol == board[i][1].symbol && board[i][1].symbol == board[i][2].symbol && board[i][2].symbol == symb) {
			highlight_cell(board[i][0], ST7735_RED, ST7735_BLACK);
			highlight_cell(board[i][1], ST7735_RED, ST7735_BLACK);
			highlight_cell(board[i][2], ST7735_RED, ST7735_BLACK);
			return 1;
		}
		
		if (board[0][i].symbol == board[1][i].symbol && board[1][i].symbol == board[2][i].symbol && board[2][i].symbol == symb) {
			highlight_cell(board[0][i], ST7735_RED, ST7735_BLACK);
			highlight_cell(board[1][i], ST7735_RED, ST7735_BLACK);
			highlight_cell(board[2][i], ST7735_RED, ST7735_BLACK);
			return 1;
		}
	}
	
	if (board[0][0].symbol == board[1][1].symbol && board[1][1].symbol == board[2][2].symbol && board[2][2].symbol == symb) {
		highlight_cell(board[0][0], ST7735_RED, ST7735_BLACK);
		highlight_cell(board[1][1], ST7735_RED, ST7735_BLACK);
		highlight_cell(board[2][2], ST7735_RED, ST7735_BLACK);
		return 1;
	}
	
	if (board[0][2].symbol == board[1][1].symbol && board[1][1].symbol == board[2][0].symbol && board[2][0].symbol == symb) {
		highlight_cell(board[0][2], ST7735_RED, ST7735_BLACK);
		highlight_cell(board[1][1], ST7735_RED, ST7735_BLACK);
		highlight_cell(board[2][0], ST7735_RED, ST7735_BLACK);
		return 1;
	}
	
	return 0;
}

// verifica daca tabla e plina
int full_board()
{
	int8_t i, j, full = 1;

	for (i = 0; i < 3; i++)
		for (j = 0; j < 3; j++)
			if (board[i][j].symbol == NO_SYMBOL) {
				full = 0;
				break;
			}
			
	return full;
}

// verifica daca e game over
int game_over()
{
	if (!won_game(O_SYMBOL) && !won_game(X_SYMBOL) && !full_board())
		return 0;
	
	return 1;
}

// sunete pentru diverse
void sunet_start() {
  int tempo = 200; // faster tempo for a quick start sound
  int buzzer = 3;
  int start_sound[] = {
  NOTE_START1, 8, NOTE_START_2, 8, NOTE_START_3, 8, NOTE_START_4, 2};
  int notes = sizeof(start_sound) / sizeof(start_sound[0]) / 2;
  int wholenote = (60000 * 4) / tempo;
  int divider = 0, noteDuration = 0;

  for (int thisNote = 0; thisNote < notes * 2; thisNote = thisNote + 2) {
    divider = start_sound[thisNote + 1];
    if (divider > 0) {
      noteDuration = (wholenote) / divider;
    } else if (divider < 0) {
      noteDuration = (wholenote) / abs(divider);
      noteDuration *= 1.5;
    }
    tone(buzzer, start_sound[thisNote], noteDuration * 0.9);
    delay(noteDuration);
    noTone(buzzer);
  }

}


void sunet_castig() {
  
  tone(buzzer, NOTE_CASTIG_1, NOTE_CASTIG_2);
  delay(100);
  tone(buzzer, NOTE_CASTIG_1, NOTE_CASTIG_3);
  delay(100);
  tone(buzzer, NOTE_CASTIG_1, NOTE_CASTIG_3);
  delay(100);
  tone(buzzer, NOTE_CASTIG_1, NOTE_CASTIG_3);
  delay(100);
  tone(buzzer, NOTE_CASTIG_1, NOTE_CASTIG_2);
  delay(100);
  tone(buzzer, NOTE_CASTIG_1, NOTE_CASTIG_2);
  delay(100);
  tone(buzzer, NOTE_CASTIG_4, NOTE_CASTIG_5);
  delay(100);
  tone(buzzer, NOTE_CASTIG_4, NOTE_CASTIG_5);
  
}

void sunet_pierdere() {

  tone(buzzer, NOTE_PIERDERE_1, 200); 
  delay(200);
  
  tone(buzzer, NOTE_PIERDERE_2, 200); 
  delay(200);
  
  tone(buzzer, NOTE_PIERDERE_4, 200); 
  delay(200);
  
  tone(buzzer, NOTE_PIERDERE_5, 200); 
  delay(200);
  
  tone(buzzer, NOTE_PIERDERE_6, 200); 
  delay(200);
  
}

void sunet_remiza() {

  tone(buzzer, NOTE_REMIZA_1, 200); 
  delay(200);
  
  tone(buzzer, NOTE_REMIZA_2, 200); 
  delay(200);
  
  tone(buzzer, NOTE_REMIZA_3, 200); 
  delay(200);
  
  tone(buzzer, NOTE_REMIZA_4, 200); 
  delay(200);
  
  tone(buzzer, NOTE_REMIZA_3, 200); 
  delay(200);
  
  tone(buzzer, NOTE_REMIZA_2, 200); 
  delay(200);
  
  tone(buzzer, NOTE_REMIZA_1, 200); 
  delay(200);
}

void yourTurnSound() {
    tone(buzzer, 600, 200);  // Ton jos pentru "Y"
    delay(200);                 // Pauză
    tone(buzzer, 800, 200);  // Ton mediu pentru "O"
    delay(200);                 // Pauză
    tone(buzzer, 600, 200);  // Ton jos pentru "U"
    delay(200);                 // Pauză
    noTone(buzzer);          // Oprește tonul
    delay(500); 
}





void setup() {
  // ******************************** //
  // PENTRU UART, AJUTA LA PRINT //
  Serial.begin(9600);
  // ******************************** //
  // apelez configurare pini
  configurare_pini();
  // printare pagina_initiala
  printare_initiala();
  
}


void loop() {
  // Verifică dacă butonul de start este apăsat
  if (!(PINB & (1 << PINB4))) {
    Serial.println("Buton de start apăsat!");

    // 1. Se pornește melodia de start
    sunet_start();
    // 2. se initializeaza tabla
    board_init(gridX, gridY, 84, 84);
    // 3. se printeaza gridul
    printare_tabla();

    game_running = true;  // Setează variabila pentru a indica că jocul a început
  }

  // verifica daca butonul de exit e apasat
  if (!(PINB & (1 << BUTTON_EXIT))) {
    apasare_exit = apasare_exit + 1;
    // daca se apasa o data atunci se inchide jocul (apare Good Bye)
    if (apasare_exit == 1) {
        printare_exit();
    }
    // daca se apasa de doua ori apare iar welcome si iei jocul de la capat
    if (apasare_exit == 2) {
        printare_initiala();
        apasare_exit = 0;  // resetare variabila
    }
    
  }

  // Logica jocului, doar dacă jocul este în desfășurare
  if (game_running) {
    if (!game_over()) {
      if (player == CPU) {
        _delay_ms(1000);
        cpu_move();
        _delay_ms(1000);
        player = HUMAN;
        info_joc();
      } else if (player == HUMAN) {
        // Verifică butoanele și efectuează acțiunile corespunzătoare
        if (citeste_butoane(BUTTON_UP)) {
          mutare(BUTTON_UP);
        } else if (citeste_butoane(BUTTON_DOWN)) {
          mutare(BUTTON_DOWN);
        } else if (citeste_butoane(BUTTON_LEFT)) {
          mutare(BUTTON_LEFT);
        } else if (citeste_butoane(BUTTON_RIGHT)) {
          mutare(BUTTON_RIGHT);
        } else if (citeste_butoane(BUTTON_OK)) {
          if (board[current_x][current_y].symbol != NO_SYMBOL) {
            highlight_cell(board[current_x][current_y], ST7735_BLUE, ST7735_BLACK);
            _delay_ms(1000);
          } else {
            mutare(OK);
            player = CPU;
            info_joc();

          }
        }
      }
    } else {
      // Jocul s-a terminat, actualizează scorurile
      no_games++;
      if (won_game(X_SYMBOL)) {
        won++;
        printare_castig();
        sunet_castig();
      } else if (won_game(O_SYMBOL)) {
        lost++;
        printare_esec();
        sunet_pierdere();
      } else {
        draw++;
        sunet_remiza();
      }
      Serial.print(won);
      Serial.print(lost);

      // Întârziere pentru a permite jucătorilor să vadă rezultatul
      _delay_ms(2000);

      // Reinitializează tabla de joc pentru un nou joc
      board_init(gridX, gridY, 84, 84);
      player = random(0, 2);
      printare_tabla();
      
    }
  }
}
